@@ -526,7 +526,7 @@ NI_size_str_ipv4(SV *ipo, char *buf)
     begin  = NI_hv_get_uv(ipo, "xs_v4_ip0", 9);
     end    = NI_hv_get_uv(ipo, "xs_v4_ip1", 9);
 
-    if ((begin == 0) && (end = 0xFFFFFFFF)) {
+    if ((begin == 0) && (end == 0xFFFFFFFF)) {
         sprintf(buf, "4294967296");
     } else {
         sprintf(buf, "%lu", end - begin + 1);
@@ -1443,6 +1443,7 @@ NI_ip_add_num(SV *ipo, const char *num)
     HV *stash;
     HV *hash;
     SV *ref;
+    int size;
 
     version = NI_hv_get_iv(ipo, "ipversion", 9);
 
